
.. _builtin_tests:

Tests that come with pyfrc
==========================

.. note:: pyfrc's testing functionality has not yet been updated
          to work with RobotPy 2020

pyfrc comes with testing functions that can be used to test basic
functionality of just about any robot, including running through a 
simulated practice match.

.. automodule:: pyfrc.tests
   :members:

.. automodule:: pyfrc.tests.basic
   :members:

Fuzz tests
----------

.. automodule:: pyfrc.tests.fuzz_test
   :members:

Docstring tests
---------------

.. automodule:: pyfrc.tests.docstring_test
   :members:
